..


.. Keep the current version number on line number 5
0.0.12
======

2023-03-22

* No functional changes
* Development tooling and workflow improvements


0.0.11
======

2023-03-21

* Supported Python versions 3.7 to 3.11
* No functional changes
* Development tooling and workflow improvements


0.0.10
======

2020-04-17

* Improve detection of circular dependencies


0.0.9
=====

2020-04-15

* Show all dependencies (or dependents) in the flat view (instead of just 1
  level deep)
* Show summary in CLI's help output
* Rewrite code


0.0.8
=====

2020-01-13

* Add '--flat' display option


0.0.7
=====

2019-11-13

* Fix issue with unknown project in reverse


0.0.6
=====

2019-11-12

* Handle unknown extras
* Add help messages for CLI arguments


0.0.5
=====

2019-11-08

* Rewrite implementation


0.0.4
=====

2019-10-24

* Sort output alphabetically


0.0.3
=====

2019-10-23

* Add 'reverse' to show tree of dependent projects


0.0.2
=====

2019-10-20

* Add possibility to specify list of projects on command line
* Add handling of extras
* Change output format


0.0.1
=====

2019-09-04


0.0.0
=====

2019-09-04


.. EOF
